@@ -27,7 +27,7 @@
 static const char description[] =
   I18N_NOOP("A KDE KPart Application");
 
-static const char version[] = "0.2";
+static const char version[] = "0.3";
 
 static KCmdLineOptions options[] =
 {
@@ -52,7 +52,7 @@ int main(int argc, char **argv)
   about.addAuthor(
                   "Tomoaki Murakami",
                   0,
-                  "solarisphere@yahoo.co.jp"
+                  "solarisphere@yahoo.co.jp", 
                   "http://voxstorm.sourceforge.jp/");
   KCmdLineArgs::init(argc, argv, &about);
   KCmdLineArgs::addCmdLineOptions( options );
