@@ -64,7 +64,7 @@ WPrefDialog::WPrefDialog(QWidget *WidgetParent, const char *cName)
   // ̥ڡ
   setupGenericPage();
 
-  setMinimumHeight(320);
+  setMinimumHeight(380);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -95,7 +95,40 @@ WPrefDialog::setFields(const SPreferences& preferencesSet)
   }
   DirChooserProject->setFileName(preferencesSet.strProjectPath);
 
-  switch ( preferencesSet.uiSampleRate ) {
+  switch ( preferencesSet.format.sampleFormat() ) {
+  case CSourceFormat::U8:
+    ComboBoxSampleFormat->setCurrentItem(0);
+    break;
+  case CSourceFormat::S16_LE:
+    ComboBoxSampleFormat->setCurrentItem(1);
+    break;
+  case CSourceFormat::S16_BE:
+    ComboBoxSampleFormat->setCurrentItem(2);
+    break;
+  case CSourceFormat::S24_LE:
+    ComboBoxSampleFormat->setCurrentItem(3);
+    break;
+  case CSourceFormat::S24_BE:
+    ComboBoxSampleFormat->setCurrentItem(4);
+    break;
+  case CSourceFormat::S32_LE:
+    ComboBoxSampleFormat->setCurrentItem(5);
+    break;
+  case CSourceFormat::S32_BE:
+    ComboBoxSampleFormat->setCurrentItem(6);
+    break;
+  case CSourceFormat::F32_LE:
+    ComboBoxSampleFormat->setCurrentItem(7);
+    break;
+  case CSourceFormat::F32_BE:
+    ComboBoxSampleFormat->setCurrentItem(8);
+    break;
+  default:
+    ComboBoxSampleFormat->setCurrentItem(1);
+    break;
+  }
+  SpinBoxChannels->setValue(preferencesSet.format.channelCount());
+  switch ( preferencesSet.format.sampleRate() ) {
   case 44100:
     ComboBoxSampleRate->setCurrentItem(0);
     break;
@@ -122,6 +155,15 @@ WPrefDialog::setFields(const SPreferences& preferencesSet)
   case 512:
     ComboBoxBuffer->setCurrentItem(3);
     break;
+  case 1024:
+    ComboBoxBuffer->setCurrentItem(4);
+    break;
+  case 2048:
+    ComboBoxBuffer->setCurrentItem(5);
+    break;
+  case 4096:
+    ComboBoxBuffer->setCurrentItem(6);
+    break;
   default:
     ComboBoxBuffer->setCurrentItem(4);
     break;
@@ -157,7 +199,10 @@ WPrefDialog::fields()
   }
   preferencesReturn.strProjectPath = DirChooserProject->fileName();
 
-  preferencesReturn.uiSampleRate = ComboBoxSampleRate->currentText().toUInt();
+  preferencesReturn.format.setSampleFormat(
+    CSourceFormat::sampleFormatIdentifier(ComboBoxSampleFormat->currentText()));
+  preferencesReturn.format.setChannelCount(SpinBoxChannels->value());
+  preferencesReturn.format.setSampleRate(ComboBoxSampleRate->currentText().toInt());
   preferencesReturn.uiBuffer     = ComboBoxBuffer->currentText().toUInt();
 
   int i, nTrack;
@@ -237,13 +282,27 @@ WPrefDialog::setupSoundSpecPage()
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_soundspec", KIcon::NoGroup, 32);
   QVBox *VBoxSound = addVBoxPage(
                           QString(i18n("Sound Spec")),
-                          i18n("Detecting sound spec"),
+                          i18n("Detecting sound spec for recording track"),
                           Pix);
   QGridLayout *GridLayout = new QGridLayout(VBoxSound, 2, 1);
 
+  // sampling format
+  QHGroupBox *GroupBoxSampleFormat = new QHGroupBox(
+          i18n("Sample format"), VBoxSound);
+  GridLayout->addWidget(GroupBoxSampleFormat, 0, 0);
+  ComboBoxSampleFormat = new KComboBox(GroupBoxSampleFormat);
+  ComboBoxSampleFormat->insertStringList(CSourceFormat::sampleFormatStringList());
+  ComboBoxSampleFormat->setCurrentItem(1);
+
+  // count of channels
+  QHGroupBox *GroupBoxChannels = new QHGroupBox(
+          i18n("Count of channels"), VBoxSound);
+  GridLayout->addWidget(GroupBoxChannels, 0, 0);
+  SpinBoxChannels = new KIntSpinBox(1, 16, 1, 2, 10, GroupBoxChannels);
+
   // sampling rate
   QHGroupBox *GroupBoxSampling = new QHGroupBox(
-          i18n("Sampling rate"), VBoxSound);
+          i18n("Sample rate"), VBoxSound);
   GridLayout->addWidget(GroupBoxSampling, 0, 0);
   ComboBoxSampleRate = new KComboBox(GroupBoxSampling);
   ComboBoxSampleRate->insertItem("44100");
@@ -259,6 +318,9 @@ WPrefDialog::setupSoundSpecPage()
   ComboBoxBuffer->insertItem("128");
   ComboBoxBuffer->insertItem("256");
   ComboBoxBuffer->insertItem("512");
+  ComboBoxBuffer->insertItem("1024");
+  ComboBoxBuffer->insertItem("2048");
+  ComboBoxBuffer->insertItem("4096");
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -347,7 +409,7 @@ WPrefDialog::setupGenericPage()
 void
 WPrefDialog::slotChangeAddState(const QString& strTrack)
 {
-  if ( strTrack != "" ) {
+  if ( !strTrack.isEmpty() ) {
     PushButtonAdd->setEnabled(true);
   } else {
     PushButtonAdd->setEnabled(false);
@@ -360,7 +422,7 @@ void
 WPrefDialog::slotAddTrackToList()
 {
   QString strTrack = LineEditName->text();
-  if ( strTrack == "" ) {
+  if ( strTrack.isEmpty() ) {
     return;
   }
 
