@@ -172,6 +172,9 @@ WVoxBase::addTrack(
   connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
           this, SLOT(slotSetScrollToAll(QObject*, int)));
 
+  connect(VoxTrackNew, SIGNAL(stateChanged()), 
+          this, SIGNAL(stateChanged()));
+
   vVoxTracks.push_back(VoxTrackNew);
   VoxTrackNew->show();
 }
@@ -240,6 +243,9 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
             this, SLOT(slotSetScrollToAll(QObject*, int)));
 
+    connect(VoxTrackNew, SIGNAL(stateChanged()), 
+            this, SIGNAL(stateChanged()));
+
     VoxTrackNew->setMaxSessionLength(timeMaxSessionLength);
 
     vVoxTracks.push_back(VoxTrackNew);
@@ -673,6 +679,7 @@ WVoxBase::slotNotifySucceedInRecording()
 
   while ( it != vVoxTracks.end() ) {
     if ( (*it)->isSetRec() ) {
+      (*it)->forceRepaintLocator();
       (*it)->slotSetStartPosition(QTime(0,0));
       (*it)->slotSetOffset(QTime(0,0));
       (*it)->slotSetLength(QTime(0,0));
