@@ -55,7 +55,6 @@ WVoxStorm::WVoxStorm(QWidget *WidgetParent, const char *cName)
 
   bDirty = false;
   slotNew();
-  bDirty = true;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -124,11 +123,13 @@ WVoxStorm::initialize()
           this, SLOT(slotChangeLength(const QString&, const QTime&)));
 
   connect(VoxBase, SIGNAL(masterPositionChanged(const QTime&)),
-          &EcaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
-  connect(&EcaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
+          &ecaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
+  connect(VoxBase, SIGNAL(stateChanged()), 
+          this, SLOT(slotChangedState()));
+  connect(&ecaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
           VoxBase, SLOT(slotChangePosition(const QTime&)));
-  connect(&EcaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
-  connect(&EcaIAManager, SIGNAL(messageGenerated(const QString&)),
+  connect(&ecaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
+  connect(&ecaIAManager, SIGNAL(messageGenerated(const QString&)),
           VoxBase, SLOT(slotWriteConsoleMessage(const QString&)));
 
   pDocVox = NULL;
@@ -259,8 +260,8 @@ WVoxStorm::writeConfigurationFile()
 void 
 WVoxStorm::applyPreferences()
 {
-  EcaIAManager.setBufferSize(preferences.uiBuffer);
-  EcaIAManager.setSoundSourceFormat(preferences.format);
+  ecaIAManager.setBufferSize(preferences.uiBuffer);
+  ecaIAManager.setSoundSourceFormat(preferences.format);
   VoxBase->setMaxSessionLength(preferences.timeSessionMax);
 }
 
@@ -485,7 +486,7 @@ WVoxStorm::queryClose()
     QApplication::setOverrideCursor(waitCursor);
     slotStop();
     if ( ToggleActionInteractive->isChecked() ) {
-      EcaIAManager.slotReleaseCurrentChainsetup();
+      ecaIAManager.slotReleaseCurrentChainsetup();
     }
     QApplication::restoreOverrideCursor();
 
@@ -642,10 +643,10 @@ void
 WVoxStorm::enterIAMode(bool bEnter)
 {
   if ( bEnter ) {
-    EcaIAManager.slotCreateNewChainsetup("VoxStorm");
+    ecaIAManager.slotCreateNewChainsetup("VoxStorm");
   } else {
     // clear chainsetup
-    EcaIAManager.slotReleaseCurrentChainsetup();
+    ecaIAManager.slotReleaseCurrentChainsetup();
   }
 }
 
@@ -710,8 +711,13 @@ void
 WVoxStorm::slotOpen()
 {
   if ( maybeSave() ) {
+    QString strTmpPath = CVoxStormGlobal::absPath(preferences.strProjectPath);
+    if ( !QFileInfo(strTmpPath).exists() ) {
+      strTmpPath = "";
+    }
+
     KURL url = KFileDialog::getOpenURL(
-                 QString::null, 
+                 strTmpPath, 
                  i18n("*.voxs|VoxStorm session files (*.voxs)\n*|All files (*)"), 
                  NULL, 
                  i18n("Open VoxStorm session file"));
@@ -744,7 +750,17 @@ WVoxStorm::slotSave()
 bool 
 WVoxStorm::slotSaveAs()
 {
-  KFileDialog dialog(QString::null,
+  QString strTmpPath = preferences.strProjectPath;
+
+  if ( !CVoxStormGlobal::queryAndCreateDir(
+         this, strTmpPath) ) {
+    strTmpPath = QString::null;
+  } else {
+    // to abs
+    strTmpPath = CVoxStormGlobal::absPath(strTmpPath);
+  }
+
+  KFileDialog dialog(strTmpPath,
                      i18n("*.voxs|VoxStorm session files (*.voxs)"), 
                      NULL,
                      i18n("Save VoxStorm session file"), 
@@ -796,14 +812,14 @@ WVoxStorm::slotPlay()
       ActionMixdown->setEnabled(false);
       VoxBase->slotChangeState(WVoxBase::Play);
       VoxBase->slotChangeMessageTab(WVoxBase::Console);
-      EcaIAManager.slotResume();
+      ecaIAManager.slotResume();
       bPause = false;
     } else {         // STOP  -> PLAY
-      EcaIAManager.slotRemoveAllChains();
+      ecaIAManager.slotRemoveAllChains();
       int nCount = VoxBase->getTrackCount();
       int i;
       for ( i = 0; i < nCount; i++ ) {
-        EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+        ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
       }
 
       ActionPlay->setEnabled(false);
@@ -811,7 +827,7 @@ WVoxStorm::slotPlay()
       ActionMixdown->setEnabled(false);
       VoxBase->slotChangeState(WVoxBase::Play);
       VoxBase->slotChangeMessageTab(WVoxBase::Console);
-      EcaIAManager.slotPlay(ToggleActionRec->isChecked());
+      ecaIAManager.slotPlay(ToggleActionRec->isChecked());
     }
   } else {
   }
@@ -833,7 +849,7 @@ WVoxStorm::slotPause()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotPause();
+    ecaIAManager.slotPause();
     ActionPlay->setEnabled(true);
     VoxBase->slotChangeState(WVoxBase::Pause);
     LabelStatusBar->setText(i18n("Pausing..."));
@@ -849,7 +865,7 @@ WVoxStorm::slotStop()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotStop();
+    ecaIAManager.slotStop();
   }
   QApplication::restoreOverrideCursor();
 }
@@ -861,7 +877,7 @@ WVoxStorm::slotJumpToStart()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotSetMasterPosition(0);
+    ecaIAManager.slotSetMasterPosition(0);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -873,7 +889,7 @@ WVoxStorm::slotRewind()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {    
-    EcaIAManager.slotRewind(preferences.iFrameSeconds);
+    ecaIAManager.slotRewind(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -885,7 +901,7 @@ WVoxStorm::slotForward()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotForward(preferences.iFrameSeconds);
+    ecaIAManager.slotForward(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -913,11 +929,11 @@ WVoxStorm::slotMixdown()
 
   LabelStatusBar->setText(i18n("Mixing..."));
 
-  EcaIAManager.slotRemoveAllChains();
+  ecaIAManager.slotRemoveAllChains();
   int nCount = VoxBase->getTrackCount();
   int i;
   for ( i = 0; i < nCount; i++ ) {
-    EcaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+    ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
   }
 
   ActionPlay->setEnabled(false);
@@ -928,7 +944,7 @@ WVoxStorm::slotMixdown()
   ActionMixdown->setEnabled(false);
   VoxBase->slotChangeState(WVoxBase::Play);
   VoxBase->slotChangeMessageTab(WVoxBase::Console);
-  EcaIAManager.slotMixdown(
+  ecaIAManager.slotMixdown(
         mixdownDialog.mixesWithPlaying(), 
         "Mixdown", 
         mixdownDialog.fileName());
@@ -1004,7 +1020,7 @@ WVoxStorm::slotChangePlaybackDevice(const QString& strTrackName,
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangePlaybackDevice(strTrackName, strPlaybackDevice);
+    ecaIAManager.slotChangePlaybackDevice(strTrackName, strPlaybackDevice);
   }
 }
 
@@ -1019,7 +1035,7 @@ WVoxStorm::slotChangeRecordingDevice(const QString& strTrackName,
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangeRecordingDevice(strTrackName, strRecordingDevice);
+    ecaIAManager.slotChangeRecordingDevice(strTrackName, strRecordingDevice);
   }
 }
 
@@ -1029,7 +1045,7 @@ void
 WVoxStorm::slotRemoveTrack(const QString& strTrackName)
 {
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotRemoveChain(strTrackName);
+    ecaIAManager.slotRemoveChain(strTrackName);
   }
 }
 
@@ -1039,7 +1055,7 @@ void
 WVoxStorm::slotChangeFileName(const QString& strTrackName, const QString&)
 {
   if ( ToggleActionInteractive->isChecked() ) {
-    if ( !EcaIAManager.isExisting(strTrackName) ) {
+    if ( !ecaIAManager.isExisting(strTrackName) ) {
       ;
     } else {
       ;
@@ -1057,7 +1073,7 @@ WVoxStorm::slotChangeLevel(const QString& strTrackName, int nLevel)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangeLevel(strTrackName, nLevel);
+    ecaIAManager.slotChangeLevel(strTrackName, nLevel);
   }
 }
 
@@ -1071,7 +1087,7 @@ WVoxStorm::slotChangePan(const QString& strTrackName, int nPan)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangePan(strTrackName, nPan);
+    ecaIAManager.slotChangePan(strTrackName, nPan);
   }
 }
 
@@ -1085,7 +1101,7 @@ WVoxStorm::slotToggleMute(const QString& strTrackName, bool bMute)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotToggleMute(strTrackName, bMute);
+    ecaIAManager.slotToggleMute(strTrackName, bMute);
   }
 }
 
@@ -1099,7 +1115,7 @@ WVoxStorm::slotToggleRec(const QString& strTrackName, bool bRec)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotToggleRec(strTrackName, bRec);
+    ecaIAManager.slotToggleRec(strTrackName, bRec);
   }
 }
 
@@ -1115,7 +1131,7 @@ WVoxStorm::slotChangeStartPosition(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangeStartPosition(strTrackName, TimeStartPosition);
+    ecaIAManager.slotChangeStartPosition(strTrackName, TimeStartPosition);
   }
 }
 
@@ -1131,7 +1147,7 @@ WVoxStorm::slotChangeOffset(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangeOffset(strTrackName, TimeOffset);
+    ecaIAManager.slotChangeOffset(strTrackName, TimeOffset);
   }
 }
 
@@ -1147,12 +1163,20 @@ WVoxStorm::slotChangeLength(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    EcaIAManager.slotChangeLength(strTrackName, TimeLength);
+    ecaIAManager.slotChangeLength(strTrackName, TimeLength);
   }
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxStorm::slotChangedState()
+{
+  this->bDirty = true;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxStorm::slotFinish()
 {
