@@ -82,7 +82,7 @@ private:
   //! Vox Stormåե̾Ρ
   QString      strSessionFile;
   //! Ecasound-IAޥ͡㡣
-  CEcaIAManager EcaIAManager;
+  CEcaIAManager ecaIAManager;
   //! 
   SPreferences preferences;
   //! DOMɥ
@@ -223,6 +223,9 @@ private slots:
   //! Ĺѹ
   void slotChangeLength(const QString& strTrackName, const QTime& TimeLength);
 
+  //! \brief ֤ѹ줿Υåȡ
+  void slotChangedState();
+
   //! \brief EcasoundIA⡼ɺλΥåȡ
   void slotFinish();
 };
