@@ -146,6 +146,9 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
 
   // mute button
   PushButtonMute = new QPushButton(HBoxButtonBase);
+  QFont font = PushButtonMute->font();
+  font.setPointSize(9);
+  PushButtonMute->setFont(font);
   PushButtonMute->setPaletteForegroundColor(QColor(0, 255, 0));
   PushButtonMute->setText("M");
   PushButtonMute->setToggleButton(true);
@@ -154,6 +157,9 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
 
   // record button
   PushButtonRec = new QPushButton(HBoxButtonBase);
+  font = PushButtonRec->font();
+  font.setPointSize(9);
+  PushButtonRec->setFont(font);
   PushButtonRec->setPaletteForegroundColor(QColor(255, 0, 0));
   PushButtonRec->setText("R");
   PushButtonRec->setToggleButton(true);
@@ -192,6 +198,14 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
           Locator, SLOT(slotSetOffset(const QTime&)));
   connect(this, SIGNAL(lengthChanged(const QTime&)), 
           Locator, SLOT(slotSetLength(const QTime&)));
+
+  // state changing signal
+  connect(FileChooserTrack, SIGNAL(fileNameChanged(const QString&)), 
+          this, SIGNAL(stateChanged()));
+  connect(IntNumInputLevel, SIGNAL(valueChanged(int)), 
+          this, SIGNAL(stateChanged()));
+  connect(IntNumInputPan, SIGNAL(valueChanged(int)), 
+          this, SIGNAL(stateChanged()));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -666,6 +680,14 @@ WVoxTrack::scrollLocator(int x)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::forceRepaintLocator()
+{
+  Locator->bind(FileChooserTrack->fileName());
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::mousePressEvent(QMouseEvent* MouseEvent)
 {
@@ -730,6 +752,7 @@ WVoxTrack::slotSetStartPosition(const QTime& time)
 
   timeStartPosition = time;
   emit startPositionChanged(timeStartPosition);
+  emit stateChanged();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -743,6 +766,7 @@ WVoxTrack::slotSetOffset(const QTime& time)
 
   timeOffset = time;
   emit offsetChanged(timeOffset);
+  emit stateChanged();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -756,6 +780,7 @@ WVoxTrack::slotSetLength(const QTime& time)
 
   timeLength = time;
   emit lengthChanged(timeLength);
+  emit stateChanged();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -776,6 +801,7 @@ WVoxTrack::slotChangePlaybackDevice()
   if ( lineEditDlg.exec() == QDialog::Accepted ) {
     strOutputDevice = lineEditDlg.text();
     emit playbackDeviceChanged(strOutputDevice);
+    emit stateChanged();
   }
 }
 
@@ -789,6 +815,7 @@ WVoxTrack::slotChangeRecordingDevice()
   if ( lineEditDlg.exec() == QDialog::Accepted ) {
     strInputDevice = lineEditDlg.text();
     emit recordingDeviceChanged(strInputDevice);
+    emit stateChanged();
   }
 }
 
@@ -800,6 +827,7 @@ WVoxTrack::slotRemove()
   QString strMessage = i18n("Are you sure to remove this track?");
   if ( KMessageBox::questionYesNo(this, strMessage) == KMessageBox::Yes ) {
     emit removed();
+    emit stateChanged();
   }
 }
 
