@@ -156,6 +156,9 @@ public:
   //! \param  x Xɸ
   void      scrollLocator(int x);
 
+  //! \brief  Ū˥褹롣
+  void      forceRepaintLocator();
+
   //! ߥ塼ȥȥܥ
   static unsigned int Mute;
   //! Ͽȥܥ
@@ -315,6 +318,10 @@ signals:
 
   //! \brief 뤵줿ȯ륷ʥ롣
   void locatorScrolled(QObject* ObjectSender, int);
+
+  //! \brief ֤ѹ줿Υʥ롣
+  //! ᥤѹʤΤǡȥåϤʤ
+  void stateChanged();
 };
 
 #endif
